from azure.cosmos import CosmosClient
import logging
import os

logger = logging.getLogger("mpf-utils.cosmosdb")

class CosmosDBContainer:

    def __init__(self, database_name:str, container_name:str, endpoint:str = None, key:str = None, conn_str:str = None):
        if not endpoint:
            endpoint = os.getenv("MPFU_COSMOSDB_ENDPOINT")
        
        if not key:
            key = os.getenv("MPFU_COSMOSDB_KEY")

        if conn_str:
            logger.info("Using connection string to connect to CosmosDB")
            client = CosmosClient.from_connection_string(conn_str)
        else:
            logger.info("Using endpoint and key to connect to CosmosDB")
            client = CosmosClient(endpoint, key)

        database = client.get_database_client(database_name)
        self.container = database.get_container_client(container_name)

    def run_query(self, query:str, parameters:list = None, results_as_list: bool = True):
        if not parameters:
            parameters = []

        try:
            items = self.container.query_items(
                query=query,
                parameters=parameters,
                enable_cross_partition_query=True,
            )
            if results_as_list:
                return list(items)
            else:
                return items
        except Exception as e:
            logger.error(f"Error in CosmosDBContainer: {e}")
            return None

    def delete_item(self, item_id:str, partition_key:str = None):
        if not partition_key:
            partition_key = item_id
        try:
            self.container.delete_item(item=item_id, partition_key=partition_key)
            return True
        except Exception as e:
            logger.error(f"Error in CosmosDBContainer: {e}")
            return False

    def upsert_item(self, item:dict):
        try:
            self.container.upsert_item(item)
            return True
        except Exception as e:
            logger.error(f"Error in CosmosDBContainer: {e}")
            return False

    def get_item(self, item_id:str, partition_key:str = None):
        if not partition_key:
            partition_key = item_id
        try:
            item = self.container.read_item(item=item_id, partition_key=partition_key)
            return item
        except Exception as e:
            logger.error(f"Error in CosmosDBContainer: {e}")
            return None

    def get_all_items(self, max_item_count: int = None, results_as_list: bool = True):
        try:
            items = self.container.read_all_items()
            if results_as_list:
                return list(items)
            else:
                return items
        except Exception as e:
            logger.error(f"Error in CosmosDBContainer: {e}")
            return None
